<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="名称" prop="warehouseName">
        <el-input
          v-model="queryParams.warehouseName"
          placeholder="请输入名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="工厂" prop="werks">
        <el-input
          v-model="queryParams.werks"
          placeholder="请输入工厂"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="状态" prop="state">
        <el-input
          v-model="queryParams.state"
          placeholder="请输入状态"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:warehouse:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:warehouse:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:warehouse:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['system:warehouse:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="warehouseList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="仓库ID" align="center" prop="warehouseId" v-if="true"/>
      <el-table-column label="仓库编号" align="center" prop="lgort" />
      <el-table-column label="名称" align="center" prop="warehouseName" />
      <el-table-column label="工厂" align="center" prop="werks" />
      <el-table-column label="类别" align="center" prop="type" />
      <el-table-column label="0,不启用
            1,启用" align="center" prop="isUseLocation" />
      <el-table-column label="管理员ID" align="center" prop="userId" />
      <el-table-column label="管理员电话" align="center" prop="userPhone" />
      <el-table-column label="坐标X" align="center" prop="coordinateX" />
      <el-table-column label="坐标Y" align="center" prop="coordinateY" />
      <el-table-column label="描述" align="center" prop="description" />
      <el-table-column label="状态" align="center" prop="state" />
      <el-table-column label="最后更新人id" align="center" prop="lastUpdatedUserId" />
      <el-table-column label="最后更新人姓名" align="center" prop="lastUpdatedUserName" />
      <el-table-column label="最后更新时间" align="center" prop="lastUpdatedDateTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.lastUpdatedDateTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:warehouse:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:warehouse:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改仓库对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="仓库编号" prop="lgort">
          <el-input v-model="form.lgort" placeholder="请输入仓库编号" />
        </el-form-item>
        <el-form-item label="名称" prop="warehouseName">
          <el-input v-model="form.warehouseName" placeholder="请输入名称" />
        </el-form-item>
        <el-form-item label="工厂" prop="werks">
          <el-input v-model="form.werks" placeholder="请输入工厂" />
        </el-form-item>
        <el-form-item label="0,不启用
            1,启用" prop="isUseLocation">
          <el-input v-model="form.isUseLocation" placeholder="请输入0,不启用
            1,启用" />
        </el-form-item>
        <el-form-item label="管理员ID" prop="userId">
          <el-input v-model="form.userId" placeholder="请输入管理员ID" />
        </el-form-item>
        <el-form-item label="管理员电话" prop="userPhone">
          <el-input v-model="form.userPhone" placeholder="请输入管理员电话" />
        </el-form-item>
        <el-form-item label="坐标X" prop="coordinateX">
          <el-input v-model="form.coordinateX" placeholder="请输入坐标X" />
        </el-form-item>
        <el-form-item label="坐标Y" prop="coordinateY">
          <el-input v-model="form.coordinateY" placeholder="请输入坐标Y" />
        </el-form-item>
        <el-form-item label="描述" prop="description">
          <el-input v-model="form.description" placeholder="请输入描述" />
        </el-form-item>
        <el-form-item label="状态" prop="state">
          <el-input v-model="form.state" placeholder="请输入状态" />
        </el-form-item>
        <el-form-item label="最后更新人id" prop="lastUpdatedUserId">
          <el-input v-model="form.lastUpdatedUserId" placeholder="请输入最后更新人id" />
        </el-form-item>
        <el-form-item label="最后更新人姓名" prop="lastUpdatedUserName">
          <el-input v-model="form.lastUpdatedUserName" placeholder="请输入最后更新人姓名" />
        </el-form-item>
        <el-form-item label="最后更新时间" prop="lastUpdatedDateTime">
          <el-date-picker clearable
            v-model="form.lastUpdatedDateTime"
            type="datetime"
            value-format="yyyy-MM-dd HH:mm:ss"
            placeholder="请选择最后更新时间">
          </el-date-picker>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button :loading="buttonLoading" type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listWarehouse, getWarehouse, delWarehouse, addWarehouse, updateWarehouse } from "@/api/basicData/warehouse";

export default {
  name: "Warehouse",
  data() {
    return {
      // 按钮loading
      buttonLoading: false,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 仓库表格数据
      warehouseList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        warehouseName: undefined,
        werks: undefined,
        type: undefined,
        state: undefined,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        warehouseId: [
          { required: true, message: "仓库ID不能为空", trigger: "blur" }
        ],
        lgort: [
          { required: true, message: "仓库编号不能为空", trigger: "blur" }
        ],
        warehouseName: [
          { required: true, message: "名称不能为空", trigger: "blur" }
        ],
        werks: [
          { required: true, message: "工厂不能为空", trigger: "blur" }
        ],
        type: [
          { required: true, message: "类别不能为空", trigger: "change" }
        ],
        // isUseLocation: [
        //   { required: true, message: "0,不启用
        //     1,启用不能为空", trigger: "blur" }
        // ],
        userId: [
          { required: true, message: "管理员ID不能为空", trigger: "blur" }
        ],
        userPhone: [
          { required: true, message: "管理员电话不能为空", trigger: "blur" }
        ],
        coordinateX: [
          { required: true, message: "坐标X不能为空", trigger: "blur" }
        ],
        coordinateY: [
          { required: true, message: "坐标Y不能为空", trigger: "blur" }
        ],
        description: [
          { required: true, message: "描述不能为空", trigger: "blur" }
        ],
        state: [
          { required: true, message: "状态不能为空", trigger: "blur" }
        ],
        displayOrder: [
          { required: true, message: "排序不能为空", trigger: "blur" }
        ],
        createdUserId: [
          { required: true, message: "创建人id不能为空", trigger: "blur" }
        ],
        createdUserName: [
          { required: true, message: "创建人姓名不能为空", trigger: "blur" }
        ],
        createdDateTime: [
          { required: true, message: "创建日期时间不能为空", trigger: "blur" }
        ],
        lastUpdatedUserId: [
          { required: true, message: "最后更新人id不能为空", trigger: "blur" }
        ],
        lastUpdatedUserName: [
          { required: true, message: "最后更新人姓名不能为空", trigger: "blur" }
        ],
        lastUpdatedDateTime: [
          { required: true, message: "最后更新时间不能为空", trigger: "blur" }
        ],
        isDeleted: [
          { required: true, message: "是否删除不能为空", trigger: "blur" }
        ]
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询仓库列表 */
    getList() {
      this.loading = true;
      listWarehouse(this.queryParams).then(response => {
        this.warehouseList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        warehouseId: undefined,
        lgort: undefined,
        warehouseName: undefined,
        werks: undefined,
        type: undefined,
        isUseLocation: undefined,
        userId: undefined,
        userPhone: undefined,
        coordinateX: undefined,
        coordinateY: undefined,
        description: undefined,
        state: undefined,
        displayOrder: undefined,
        createdUserId: undefined,
        createdUserName: undefined,
        createdDateTime: undefined,
        lastUpdatedUserId: undefined,
        lastUpdatedUserName: undefined,
        lastUpdatedDateTime: undefined,
        isDeleted: undefined
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.warehouseId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加仓库";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.loading = true;
      this.reset();
      const warehouseId = row.warehouseId || this.ids
      getWarehouse(warehouseId).then(response => {
        this.loading = false;
        this.form = response.data;
        this.open = true;
        this.title = "修改仓库";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          this.buttonLoading = true;
          if (this.form.warehouseId != null) {
            updateWarehouse(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            }).finally(() => {
              this.buttonLoading = false;
            });
          } else {
            addWarehouse(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            }).finally(() => {
              this.buttonLoading = false;
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const warehouseIds = row.warehouseId || this.ids;
      this.$modal.confirm('是否确认删除仓库编号为"' + warehouseIds + '"的数据项？').then(() => {
        this.loading = true;
        return delWarehouse(warehouseIds);
      }).then(() => {
        this.loading = false;
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {
      }).finally(() => {
        this.loading = false;
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/warehouse/export', {
        ...this.queryParams
      }, `warehouse_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
